/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Ear.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.ant.archive;

import java.util.ArrayList;
import java.util.List;

import org.apache.tools.ant.Project;
import org.apache.tools.ant.Task;
import org.ow2.easybeans.ant.archive.api.IEar;
import org.ow2.easybeans.ant.archive.exploded.EarExploded;
import org.ow2.easybeans.ant.archive.file.EarFile;
import org.ow2.easybeans.ant.archive.info.EarInfo;

/**
 * Task that creates an Ear archive (.ear file or .ear directory).
 * @author Florent Benoit
 */
public class Ear extends AbsArchive {

    /**
     * List of War to package in this EAR.
     */
    private List<War> wars = null;

    /**
     * List of EJB to package in this EAR.
     */
    private List<Ejb> ejbs = null;

    /**
     * Default constructor.
     */
    public Ear() {
        super();
        this.wars = new ArrayList<War>();
        this.ejbs = new ArrayList<Ejb>();
    }

    /**
     * Add a given war archive.
     * @param war the given archive
     */
    public void addConfiguredWar(final War war) {
        wars.add(war);
    }

    /**
     * Add a given Ejb archive.
     * @param ejb the given archive
     */
    public void addConfiguredEjb(final Ejb ejb) {
        ejbs.add(ejb);
    }

    /**
     * Execute the task.
     */
    @Override
    public void execute() {

        log("Building Ear in '" + getDest() + "'.", Project.MSG_INFO);

        IEar ear = null;

        // 2 cases, exploded mode or not
        if (isExploded()) {
            ear = new EarExploded(getProject());
        } else {
            ear = new EarFile(getProject());
        }

        // Set the name of the task
        ((Task) ear).setTaskName(getTaskName());

        // Build the info object
        EarInfo earInfo = new EarInfo();
        ear.setEarInfo(earInfo);

        // Fill archive properties
        updateArchiveInfo(earInfo);

        // set children
        earInfo.setEjbs(ejbs);
        earInfo.setWars(wars);

        // Execute the task
        ear.execute();

    }

}
