/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ArchiveInfo.java 2530 2008-02-27 17:58:05Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.ant.archive.info;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.apache.tools.ant.types.FileSet;

/**
 * Class that holds information about an archive.
 * @author Florent Benoit
 */
public class ArchiveInfo {

    /**
     * Reference to the standard deployment descriptor.
     */
    private File dd = null;

    /**
     * Reference to the specific deployment descriptor.
     */
    private File specificDD = null;

    /**
     * Reference to the persistence deployment descriptor.
     */
    private File persistenceDD = null;

    /**
     * Full path to the archive.
     */
    private File dest = null;

    /**
     * List of fileset used to add files.
     */
    private List<FileSet> fileSetList = null;

    /**
     * Exploded mode or not ? (default = file).
     */
    private boolean exploded = false;

    /**
     * Default constructor.
     */
    public ArchiveInfo() {
        this.fileSetList = new ArrayList<FileSet>();

    }

    /**
     * Add the given fileset to the list of existing fileset.
     * @param fileSet the fileset to add.
     */
    public void addFileSet(final FileSet fileSet) {
        fileSetList.add(fileSet);
    }

    /**
     * Gets the list of fileset to include in the archive.
     * @return the list of fileset to include in the archive.
     */
    public List<FileSet> getFileSetList() {
        return fileSetList;
    }

    /**
     * Sets the reference to the deployment descriptor.
     * @param dd the given deployment descriptor.
     */
    public void setDD(final File dd) {
        this.dd = dd;
    }

    /**
     * Gets the reference to the deployment descriptor.
     * @return the standard deployment descriptor.
     */
    public File getDD() {
        return dd;
    }

    /**
     * Sets the reference to the specific deployment descriptor.
     * @param specificDD the given specific deployment descriptor.
     */
    public void setSpecificDD(final File specificDD) {
        this.specificDD = specificDD;
    }

    /**
     * Gets the reference to the specific deployment descriptor.
     * @return the specific deployment descriptor.
     */
    public File getSpecificDD() {
        return specificDD;
    }

    /**
     * Sets the reference to the persistence deployment descriptor.
     * @param persistenceDD the given persistence deployment descriptor.
     */
    public void setPersistenceDD(final File persistenceDD) {
        this.persistenceDD = persistenceDD;
    }

    /**
     * Gets the reference to the persistence deployment descriptor.
     * @return the persistence deployment descriptor.
     */
    public File getPersistenceDD() {
        return persistenceDD;
    }

    /**
     * Sets the path to the archive that will be built.
     * @param dest the reference to resulting archive path.
     */
    public void setDest(final File dest) {
        this.dest = dest;
    }

    /**
     * Gets the path to the archive that will be built.
     * @return the reference to resulting archive path.
     */
    public File getDest() {
        return dest;
    }

    /**
     * Sets the exploded mode to true or false.
     * @param exploded boolean true/false
     */
    public void setExploded(final boolean exploded) {
        this.exploded = exploded;
    }

    /**
     * Gets the state : exploded mode or not ?
     * @return the state : exploded mode or not ?
     */
    public boolean isExploded() {
        return exploded;
    }
}
