/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EZBServer.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.api;

import java.util.Map;

import org.ow2.easybeans.api.components.EZBComponentManager;
import org.ow2.util.ee.deploy.api.archive.IArchive;

/**
 * Defines an EasyBeans server.
 * @author Florent Benoit
 */
public interface EZBServer {

    /**
     * Gets the id of this embedded server.
     * @return the id of this server.
     */
    Integer getID();

    /**
     * Creates and adds an ejb3 container to the managed container.
     * @param archive jar file or exploded archive.
     * @return the created container.
     */
    EZBContainer createContainer(final IArchive archive);

    /**
     * Gets a container managed by this server.
     * @param id the container id.
     * @return the container if it is found, else null.
     */
    EZBContainer getContainer(final String id);

    /**
     * Gets a container managed by this server.
     * @param archive the archive used by the given container.
     * @return the container if it is found, else null.
     */
    EZBContainer findContainer(final IArchive archive);

    /**
     * Remove a given container.
     * @param container the container to be removed.
     */
    void removeContainer(final EZBContainer container);

    /**
     * @return Returns the deployed containers.
     */
    Map<String, EZBContainer> getContainers();

    /**
     * @return the ComponentManager used by this instance.
     */
    EZBComponentManager getComponentManager();
}
