package org.ow2.easybeans.deployment.annotations.analyzer.configurator.metadata;

import java.util.Map;

import org.ow2.easybeans.asm.AnnotationVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxAnnotationResourceVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxEjbEJBVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxPersistencePersistenceContextVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxPersistencePersistenceUnitVisitor;
import org.ow2.easybeans.deployment.metadata.interfaces.ISharedMetadata;

/**
 * Utility class.
 * @author Gael Lalire
 */
public final class CommonMetadataConfigurator {

    /**
     * Constructor.
     */
    private CommonMetadataConfigurator() {
    }

    /**
     * @param <T> type
     * @param annotationVisitors annotationVisitors
     * @param annotationMetadata am
     */
    public static <T extends ISharedMetadata> void initVisitor(final Map<String, AnnotationVisitor> annotationVisitors,
            final T annotationMetadata) {

        // add @EJB
        annotationVisitors.put(JavaxEjbEJBVisitor.TYPE, new JavaxEjbEJBVisitor<T>(annotationMetadata));

        // add @Resource
        annotationVisitors.put(JavaxAnnotationResourceVisitor.TYPE, new JavaxAnnotationResourceVisitor<T>(annotationMetadata));

        // add @PersistenceContext
        annotationVisitors.put(JavaxPersistencePersistenceContextVisitor.TYPE, new JavaxPersistencePersistenceContextVisitor<T>(
                annotationMetadata));

        // add @PersistenceUnit
        annotationVisitors.put(JavaxPersistencePersistenceUnitVisitor.TYPE, new JavaxPersistencePersistenceUnitVisitor<T>(
                annotationMetadata));

    }

}
