/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ObjectArrayAnnotationVisitor.java 2372 2008-02-08 18:18:37Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.analyzer.visitors;

import java.util.ArrayList;
import java.util.List;

import org.ow2.easybeans.asm.AnnotationVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.AnnotationType;

/**
 * This class manages the handling of Array[] type like String[] value().
 * @param <T> the type of annotation metadata.
 * @param <V> the type of class / erasure (for values).
 * @author Florent Benoit
 */
public abstract class ObjectArrayAnnotationVisitor<T, V>
                 extends AbsAnnotationVisitor<T>
                 implements AnnotationVisitor, AnnotationType {

    /**
     * Array.
     */
    private List<V> arrayObjects = null;

    /**
     * Init method.
     */
    public void init() {
        this.arrayObjects = new ArrayList<V>();
    }

    /**
     * Constructor.
     * @param annotationMetadata linked to an annotation metadata.
     */
    public ObjectArrayAnnotationVisitor(final T annotationMetadata) {
        super(annotationMetadata);
        init();
    }


    /**
     * Visits a primitive value of the annotation.
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link org.ow2.easybeans.asm.Type}.
     */
    @Override
    @SuppressWarnings("unchecked")
    public void visit(final String name, final Object value) {
        this.arrayObjects.add((V) value);
    }

    /**
     * @return list of objects
     */
    public List<V> getArrayObjects() {
        return this.arrayObjects;
    }

}
