/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JApplicationException.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.impl;

import java.lang.annotation.Annotation;

import javax.ejb.ApplicationException;

/**
 * Acts as an implementation of &#64;{@link javax.ejb.ApplicationException}
 * annotation.
 * @author Florent Benoit
 */
public class JApplicationException implements ApplicationException {

    /**
     * Name of this element (Deployment desc).
     */
    public static final String NAME = "application-exception";

    /**
     * Container rollback the transaction ? if an exception is thrown.
     */
    private boolean rollback = false;

    /**
     * Name of the class that is flagged as ApplicationException.
     */
    private String className = null;

    /**
     * Build an object which represents &#64;{@link javax.ejb.ApplicationException}
     * annotation.<br>
     * Default value for rollback is false.
     */
    public JApplicationException() {
        this(false);
    }

    /**
     * Build an object which represents &#64;{@link javax.ejb.ApplicationException}
     * annotation with a given boolean.<br>
     * @param rollback true/false (false is a default value)
     */
    public JApplicationException(final boolean rollback) {
        this(null, rollback);
    }

    /**
     * Build an object which represents &#64;{@link javax.ejb.ApplicationException}
     * annotation with a given boolean.<br>
     * @param className the name of the class which is the application
     *        exception.
     * @param rollback true/false (false is a default value)
     */
    public JApplicationException(final String className, final boolean rollback) {
        this.className = className;
        this.rollback = rollback;
    }

    /**
     * @return the retainIfException value (true/false)
     */
    public boolean rollback() {
        return rollback;
    }

    /**
     * @return the class name.
     */
    public String getClassName() {
        return className;
    }

    /**
     * @return annotation type
     */
    public Class<? extends Annotation> annotationType() {
        return ApplicationException.class;
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));
        // rollback
        sb.append("[rollback=");
        sb.append(rollback);
        if (className != null) {
            sb.append(",className=");
            sb.append(className);
        }
        sb.append("]");
        return sb.toString();
    }
}
