/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EJB3DeploymentDesc.java 2501 2008-02-26 11:02:03Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.xml;

import java.net.URL;

import org.ow2.easybeans.deployment.xml.parsing.EJB3DeploymentDescLoader;
import org.ow2.easybeans.deployment.xml.parsing.ParsingException;
import org.ow2.easybeans.deployment.xml.struct.EJB3;
import org.ow2.util.ee.deploy.api.archive.ArchiveException;
import org.ow2.util.ee.deploy.api.archive.IArchive;

/**
 * Utility class to get a deployment descriptor.
 * @author Florent Benoit
 */
public final class EJB3DeploymentDesc {

    /**
     * Utility class, no public constructor.
     */
    private EJB3DeploymentDesc() {

    }

    /**
     * Gets EJB3 for a given archive.
     * @param archive file/directory.
     * @throws EJB3DeploymentDescException if no xml is present.
     * @return EJB3 instance or null.
     */
    public static EJB3 getEjb3(final IArchive archive) throws EJB3DeploymentDescException {

        // Get XML entry
        URL ejbjarXmlURL = null;
        try {
            ejbjarXmlURL = archive.getResource("META-INF/ejb-jar.xml");
        } catch (ArchiveException e) {
            throw new EJB3DeploymentDescException("Cannot get resource 'META-INF/ejb-jar.xml' on the archive '"
                    + archive.getName() + "'.");
        }

        EJB3 ejb3 = null;
        // Get EJB3 object (if url valid)
        if (ejbjarXmlURL != null) {
             try {
                 ejb3 = EJB3DeploymentDescLoader.loadDeploymentDescriptor(ejbjarXmlURL);
            } catch (ParsingException e) {
                throw new EJB3DeploymentDescException("Cannot parse URL '" + ejbjarXmlURL + "'.", e);
            }
        }
        return ejb3;
    }

}
