/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EJB3.java 2447 2008-02-14 17:09:49Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.xml.struct;

/**
 * This class represents an EJB-Jar deployment descriptor.
 * @author Florent Benoit
 */
public class EJB3 {

    /**
     * Enterprise-beans element.
     */
    private EnterpriseBeans enterpriseBeans = null;

    /**
     * interceptors element.
     */
    private Interceptors interceptors = null;

    /**
     * assembly-descriptor element.
     */
    private AssemblyDescriptor assemblyDescriptor = null;

    /**
     * metadataComplete.
     */
    private boolean metadataComplete;

    /**
     * Gets the enterprise-beans element.
     * @return the enterprise-beans
     */
    public EnterpriseBeans getEnterpriseBeans() {
        return enterpriseBeans;
    }

    /**
     * Sets the enterprise-beans element.
     * @param enterpriseBeans the element to set.
     */
    public void setEnterpriseBeans(final EnterpriseBeans enterpriseBeans) {
        this.enterpriseBeans = enterpriseBeans;
    }

    /**
     * Gets the interceptors element.
     * @return the interceptors
     */
    public Interceptors getInterceptors() {
        return interceptors;
    }

    /**
     * Sets the interceptors element.
     * @param interceptors the element to set.
     */
    public void setInterceptors(final Interceptors interceptors) {
        this.interceptors = interceptors;
    }

    /**
     * Gets the assembly-descriptor element.
     * @return the assembly-descriptor
     */
    public AssemblyDescriptor getAssemblyDescriptor() {
        return assemblyDescriptor;
    }

    /**
     * Sets the assembly-descriptor element.
     * @param assemblyDescriptor the element to set.
     */
    public void setAssemblyDescriptor(final AssemblyDescriptor assemblyDescriptor) {
        this.assemblyDescriptor = assemblyDescriptor;
    }

    /**
     * Set metadataComplete.
     * @param metadataComplete true if deployment descriptor contains all information
     */
    public void setMetadataComplete(final boolean metadataComplete) {
        this.metadataComplete = metadataComplete;
    }

    /**
     * Get metadataComplete.
     * @return true if deployment descriptor contains all information
     */
    public boolean isMetadataComplete() {
        return metadataComplete;
    }

}
